# author: Lukas J. Splitthoff, Miguel Carrera Beloa
# date: 2023-10-30
# purpose: condensed matter hamiltonian of the SSH model

import numpy as np
import scipy.linalg as sp
import matplotlib.pyplot as plt


def hamiltonianSSH_cm_simple(n, epsilon, v, w):
    '''
    Returns the tight binding Hamiltonian of a finite SSH chain with on-site energy epsilon and hopping amplitudes v and w.
    '''

    # construct the Hamiltonian matrix
    ham = np.zeros((2*n, 2*n))

    for i in range(2*n):
        ham[i, i] = epsilon
        if i == 2*n-1:
            break
        elif i%2 == 0:
            ham[i, i+1] = v
            ham[i+1, i] = v
        else:
            ham[i, i+1] = w
            ham[i+1, i] = w

    # diagonalize the Hamiltonian
    eigvals, eigvecs = sp.eigh(ham)

    return eigvals, eigvecs, ham

def sublattice_operator(n):
    c = np.kron(np.eye(n), np.array([[1, 0], [0, -1]])) 
    return c